@@ -305,20 +305,28 @@ void Focus::newFITS(IBLOB *bp)
     ISD::CCDChip *targetChip = currentCCD->getChip(ISD::CCDChip::PRIMARY_CCD);
     FITSView *targetImage = targetChip->getImage(FITS_FOCUS);
 
-    FITSImage *image_data = targetImage->getImageData();
-
-    currentCCD->disconnect(this);
-
     if (targetImage == NULL)
     {
         qDebug() << "Error: targetImage is NULL!" << endl;
         return;
     }
 
+    FITSImage *image_data = targetImage->getImageData();
+
+    currentCCD->disconnect(this);
+
     image_data->findStars();
 
     double currentHFR= image_data->getHFR(HFR_MAX);
 
+    qDebug() << "curent HFR is " << currentHFR << endl;
+
+    if (currentHFR == -1)
+    {
+        currentHFR = image_data->getHFR();
+        qDebug() << "and now hfr is " << currentHFR << endl;
+    }
+
     HFRText = QString("%1").arg(currentHFR, 0,'g', 3);
 
     if (inFocusLoop == false && focusType == FOCUS_MANUAL && HFR == -1)
