@@ -59,103 +59,180 @@ bool DeepSkyComponent::selected()
 void DeepSkyComponent::update( KSNumbers* )
 {}
 
-
 void DeepSkyComponent::loadData()
 {
+
     KStarsData* data = KStarsData::Instance();
-    //Check whether we need to concatenate a plit NGC/IC catalog
+    //Check whether we need to concatenate a split NGC/IC catalog
     //(i.e., if user has downloaded the Steinicke catalog)
     mergeSplitFiles();
 
-    KSFileReader fileReader;
-    if ( ! fileReader.open( "ngcic.dat" ) ) return;
+    QList< QPair<QString,KSParser::DataTypes> > sequence;
+    QList<int> widths;
+    sequence.append(qMakePair(QString("Flag"), KSParser::D_QSTRING));
+    widths.append(1);
 
-    fileReader.setProgress( i18n("Loading NGC/IC objects"), 13444, 10 );
+    sequence.append(qMakePair(QString("ID"), KSParser::D_INT));
+    widths.append(4);
 
-    while ( fileReader.hasMoreLines() ) {
-        QString line, con, ss, name, name2, longname;
-        QString cat, cat2, sgn;
-        float mag(1000.0), ras, a, b;
-        int type, ingc, imess(-1), rah, ram, dd, dm, ds, pa;
+    sequence.append(qMakePair(QString("suffix"), KSParser::D_QSTRING));
+    widths.append(1);
+
+    sequence.append(qMakePair(QString("RA_H"), KSParser::D_INT));
+    widths.append(2);
+
+    sequence.append(qMakePair(QString("RA_M"),KSParser::D_INT));
+    widths.append(2);
+
+    sequence.append(qMakePair(QString("RA_S"),KSParser::D_FLOAT));
+    widths.append(4);
+
+    sequence.append(qMakePair(QString("D_Sign"),KSParser::D_QSTRING));
+    widths.append(2);
+
+    sequence.append(qMakePair(QString("Dec_d"),KSParser::D_INT));
+    widths.append(2);
+
+    sequence.append(qMakePair(QString("Dec_m"),KSParser::D_INT));
+    widths.append(2);
+
+    sequence.append(qMakePair(QString("Dec_s"),KSParser::D_INT));
+    widths.append(2);
+
+    sequence.append(qMakePair(QString("BMag"),KSParser::D_QSTRING));
+    widths.append(6);
+
+    sequence.append(qMakePair(QString("type"),KSParser::D_INT));
+    widths.append(2);
+
+    sequence.append(qMakePair(QString("a"),KSParser::D_FLOAT));
+    widths.append(6);
+
+    sequence.append(qMakePair(QString("b"),KSParser::D_FLOAT));
+    widths.append(6);
+
+    sequence.append(qMakePair(QString("pa"),KSParser::D_QSTRING));
+    widths.append(4);
+
+    sequence.append(qMakePair(QString("PGC"),KSParser::D_INT));
+    widths.append(7);
+
+    sequence.append(qMakePair(QString("other cat"),KSParser::D_QSTRING));
+    widths.append(4);
+
+    sequence.append(qMakePair(QString("other1"),KSParser::D_QSTRING));
+    widths.append(6);
+
+    sequence.append(qMakePair(QString("other2"),KSParser::D_QSTRING));
+    widths.append(6);
+
+    sequence.append(qMakePair(QString("Messr"),KSParser::D_QSTRING));
+    widths.append(2);
+
+    sequence.append(qMakePair(QString("MessrNum"),KSParser::D_INT));
+    widths.append(4);
+
+    sequence.append(qMakePair(QString("Longname"),KSParser::D_QSTRING));
+    //No width to be appended for last sequence object
+
+    QString file_name = KStandardDirs::locate( "appdata",
+                                           QString("ngcic.dat") );
+    KSParser deep_sky_parser(file_name, '#', sequence, widths);
+
+    deep_sky_parser.SetProgress( i18n("Loading NGC/IC objects"), 13444, 10 );
+    kDebug() << "Loading NGC/IC objects";
+
+    QHash<QString,QVariant> row_content;
+    while (deep_sky_parser.HasNextRow()) {
+        row_content = deep_sky_parser.ReadNextRow();
+
+        QString iflag;
+        QString cat;
+        iflag = row_content["Flag"].toString().mid( 0, 1 ); //check for NGC/IC catalog flag
+        /*
+        Q_ASSERT(iflag == "I" || iflag == "N" || iflag == " ");
+        // (spacetime): ^ Why an assert? Change in implementation of ksparser
+        //  might result in crash for no reason.
+        // n.b. We also allow non-NGC/IC objects which have a blank iflag
+        */
+
+        float mag(1000.0);
+        int type, ingc, imess(-1), pa;
         int pgc, ugc;
-        QChar iflag;
+        QString con, ss, name, name2, longname;
+        QString cat2;
 
-        line = fileReader.readLine();
+        // Designation
+        if ( iflag == "I" ) cat = "IC";
+        else if ( iflag == "N" ) cat = "NGC";
 
-        //Ignore comment lines
-        while ( line.at(0) == '#' && fileReader.hasMoreLines() ) line = fileReader.readLine();
-
-        //Ignore lines with no coordinate values
-        while ( line.mid(6,8).trimmed().isEmpty() && fileReader.hasMoreLines() ) {
-            line = fileReader.readLine();
-        }
-
-        iflag = line.at( 0 ); //check for NGC/IC catalog flag
-        Q_ASSERT( iflag == 'I' || iflag == 'N' || iflag == ' '); // n.b. We also allow non-NGC/IC objects which have a blank iflag
-        if ( iflag == 'I' ) cat = "IC";
-        else if ( iflag == 'N' ) cat = "NGC";
-
-        ingc = line.mid( 1, 4 ).toInt();  // NGC/IC catalog number
+        ingc = row_content["ID"].toInt();  // NGC/IC catalog number
         if ( ingc==0 ) cat.clear(); //object is not in NGC or IC catalogs
 
-        QString suffix = line.at( 5 );
-        if ( suffix  == " " )
-            suffix = QString(); // Empty string for no suffix
+        QString suffix = row_content["suffix"].toString(); // multipliticity suffixes, eg: the 'A' in NGC 4945A
+
+        Q_ASSERT( suffix.isEmpty() || ( suffix.at( 0 ) >= QChar( 'A' ) && suffix.at( 0 ) <= QChar( 'Z' ) ) || (suffix.at( 0 ) >= QChar( 'a' ) && suffix.at( 0 ) <= QChar( 'z' ) ) );
 
         //coordinates
-        rah = line.mid( 6, 2 ).toInt();
-        ram = line.mid( 8, 2 ).toInt();
-        ras = line.mid( 10, 4 ).toFloat();
-        sgn = line.mid( 15, 1 ); //don't use at(), because it crashes on invalid index
-        dd = line.mid( 16, 2 ).toInt();
-        dm = line.mid( 18, 2 ).toInt();
-        ds = line.mid( 20, 2 ).toInt();
+        int rah = row_content["RA_H"].toInt();
+        int ram = row_content["RA_M"].toInt();
+        float ras = row_content["RA_S"].toFloat();
+        QString sgn = row_content["D_Sign"].toString();
+        int dd = row_content["Dec_d"].toInt();
+        int dm = row_content["Dec_m"].toInt();
+        int ds = row_content["Dec_s"].toInt();
 
-        Q_ASSERT( 0.0 <= rah && rah < 24.0 );
-        Q_ASSERT( 0.0 <= ram && ram < 60.0 );
-        Q_ASSERT( 0.0 <= ras && ras < 60.0 );
-        Q_ASSERT( 0.0 <= dd && dd <= 90.0 );
-        Q_ASSERT( 0.0 <= dm && dm < 60.0 );
-        Q_ASSERT( 0.0 <= ds && ds < 60.0 );
+        if ( !( (0.0 <= rah && rah < 24.0) ||
+             (0.0 <= ram && ram < 60.0) ||
+             (0.0 <= ras && ras < 60.0) ||
+             (0.0 <= dd && dd <= 90.0) ||
+             (0.0 <= dm && dm < 60.0) ||
+               (0.0 <= ds && ds < 60.0) ) ) {
+          kDebug() << "Bad coordinates while processing NGC/IC object: " << cat << ingc;
+          kDebug() << "RA H:M:S = " << rah << ":" << ram << ":" << ras << "; Dec D:M:S = " << dd << ":" << dm << ":" << ds;
+          Q_ASSERT( false );
+        }
+
+        //Ignore lines with no coordinate values if not debugging
+        if (rah==0 && ram==0 && ras==0)
+            continue;
 
         //B magnitude
-        ss = line.mid( 23, 4 );
-        if (ss == "    " ) { mag = 99.9f; } else { mag = ss.toFloat(); }
+        ss = row_content["BMag"].toString();
+        if (ss == "") { mag = 99.9f; } else { mag = ss.toFloat(); }
 
         //object type
-        type = line.mid( 28, 2 ).toInt();
+        type = row_content["type"].toInt();
 
         //major and minor axes
-        ss = line.mid( 31, 5 );
-        if (ss == "      " ) { a = 0.0; } else { a = ss.toFloat(); }
-        ss = line.mid( 37, 5 );
-        if (ss == "     " ) { b = 0.0; } else { b = ss.toFloat(); }
+        float a = row_content["a"].toFloat();
+        float b = row_content["b"].toFloat();
+
         //position angle.  The catalog PA is zero when the Major axis
         //is horizontal.  But we want the angle measured from North, so
         //we set PA = 90 - pa.
-        ss = line.mid( 43, 3 );
-        if (ss == "   " ) { pa = 90; } else { pa = 90 - ss.toInt(); }
+        ss = row_content["pa"].toString();
+        if (ss == "" ) { pa = 90; } else { pa = 90 - ss.toInt(); }
 
         //PGC number
-        ss = line.mid( 47, 6 );
-        if (ss == "      " ) { pgc = 0; } else { pgc = ss.toInt(); }
+        pgc = row_content["PGC"].toInt();
 
         //UGC number
-        if ( line.mid( 54, 3 ) == "UGC" ) {
-            ugc = line.mid( 58, 5 ).toInt();
+        if (row_content["other cat"].toString().trimmed() == "UGC") {
+            ugc = row_content["other1"].toString().toInt();
         } else {
             ugc = 0;
         }
 
         //Messier number
-        if ( line.mid( 70,1 ) == "M" ) {
+        if ( row_content["Messr"].toString().trimmed() == "M" ) {
             cat2 = cat;
-            if ( ingc==0 ) cat2.clear();
+            if ( ingc == 0 ) cat2.clear();
             cat = 'M';
-            imess = line.mid( 72, 3 ).toInt();
+            imess = row_content["MessrNum"].toInt();
         }
 
-        longname = line.mid( 76, line.length() ).trimmed();
+        longname = row_content["Longname"].toString();
 
         dms r;
         r.setH( rah, ram, int(ras) );
@@ -165,24 +242,21 @@ void DeepSkyComponent::loadData()
 
         bool hasName = true;
         QString snum;
-        if ( cat=="IC" || cat=="NGC" ) {
-            snum.setNum( ingc );
-            name = cat + ' ' + snum + suffix;
-        } else if ( cat=="M" ) {
+        if (cat=="IC" || cat=="NGC") {
+            snum.setNum(ingc);
+	    name = cat + ' ' + ( ( suffix.isEmpty() ) ? snum : ( snum + suffix ) );
+        } else if (cat == "M") {
             snum.setNum( imess );
-            name = cat + ' ' + snum;
-            if ( cat2=="NGC" ) {
+            name = cat + ' ' + snum; // Note: Messier has no suffixes
+            if (cat2 == "NGC" || cat2 == "IC") {
                 snum.setNum( ingc );
-                name2 = cat2 + ' ' + snum + suffix;
-            } else if ( cat2=="IC" ) {
-                snum.setNum( ingc );
-                name2 = cat2 + ' ' + snum + suffix;
+		name2 = cat2 + ' ' + ( ( suffix.isEmpty() ) ? snum : ( snum + suffix ) );
             } else {
                 name2.clear();
             }
         }
         else {
-            if ( ! longname.isEmpty() ) name = longname;
+            if (!longname.isEmpty()) name = longname;
             else {
                 hasName = false;
                 name = i18n( "Unnamed Object" );
@@ -234,7 +308,7 @@ void DeepSkyComponent::loadData()
         if ( ! longname.isEmpty() && longname != name )
             objectNames(type).append( longname );
 
-        fileReader.showProgress();
+        deep_sky_parser.ShowProgress();
     }
 }
 
@@ -538,11 +612,11 @@ SkyObject* DeepSkyComponent::objectNearest( SkyPoint *p, double &maxrad ) {
     // -jbb: this is the template of the non-indexed way
     //
     //foreach ( SkyObject *o, m_MessierList ) {
-    //	r = o->angularDistanceTo( p ).Degrees();
-    //	if ( r < rTry ) {
-    //		rTry = r;
-    //		oTry = o;
-    //	}
+    //  r = o->angularDistanceTo( p ).Degrees();
+    //  if ( r < rTry ) {
+    //          rTry = r;
+    //          oTry = o;
+    //  }
     //}
 
     rTry *= 0.5;
