@@ -15,29 +15,29 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "planetmoons.h"
 
+#include <kdebug.h>
+
+#include "planetmoons.h"
 #include "ksnumbers.h"
 #include "ksplanetbase.h"
 #include "kssun.h"
 #include "trailobject.h"
 
-#include <QDebug>
-
-PlanetMoons::~PlanetMoons()
-{
-    qDeleteAll(Moon);
+PlanetMoons::PlanetMoons(){
 }
 
-QString PlanetMoons::name(int id) const
-{
+PlanetMoons::~PlanetMoons(){
+    qDeleteAll( Moon );
+}
+
+QString PlanetMoons::name( int id ) const {
     return Moon[id]->translatedName();
 }
 
-void PlanetMoons::EquatorialToHorizontal(const dms *LST, const dms *lat)
-{
-    int nmoons = nMoons();
-
-    for (int i = 0; i < nmoons; ++i)
-        moon(i)->EquatorialToHorizontal(LST, lat);
+void PlanetMoons::EquatorialToHorizontal( const dms *LST, const dms *lat ) {
+  int nmoons = nMoons();
+  
+  for ( int i=0; i<nmoons; ++i )
+        moon(i)->EquatorialToHorizontal( LST, lat );
 }
